define([
    "jquery",
    "Magento_Ui/js/modal/modal",
    "Magento_Customer/js/customer-data",
    "jquery/ui",
    "mage/cookies",
    "mage/translate"
], function ($, modal, customerData) {
    "use strict";

    //creating jquery widget
    $.widget('filoblu.newsletter_popup', {
        popup: {},
        _create: function () {
            
            var newsletterData = customerData.get('newsletter-config');

            newsletterData.subscribe(function (newsletterConfig) {
                if (!this.popup.created) {
                    this.createPopup(newsletterConfig.is_already_subscribed);
                }
                ;
            }, this);

            if (typeof newsletterData().is_already_subscribed === "undefined") {
                customerData.reload(['newsletter-config'], false);
            } else {
                this.createPopup(newsletterData().is_already_subscribed);
            }

        },
        createPopup: function (is_already_subscribed) {
            
            this.popup.created = true;
            
            var options = this.options;
            
            var auto_open = true;
            
            if (is_already_subscribed) {
                auto_open = false;
            }
            
            if ($.mage.cookies.get(options.cookie_name)) {
                auto_open = false;
            }
            
            var me = this;

            var optionsPopup = {
                type: 'popup',
                responsive: true,
                modalClass: 'newletterModal',
                innerScroll: true,
                autoOpen: auto_open,
                title: $.mage.__('Subscribe To Our Newsletter'),
                buttons: [],
                closed: function () {

                    if (!$.mage.cookies.get(options.cookie_name)) {
                        var toDay = new Date();//for getting todays date.
                        toDay.setTime(toDay.getTime());
                        var expaireTime = options.cookie_duration * 1000;
                        var expaireDate = new Date(toDay.getTime() + (expaireTime));

                        $.mage.cookies.set(options.cookie_name, 'subscribed', {"expires": expaireDate});
                    }
                }
            };

            var popup = modal(optionsPopup, $(options.popup_id));

            $(options.submit_btn).on("click", function () {
                me.removeMsg($(options.popup_id), 'error-msg');
                if ($(options.submit_form).valid()) {

                    $.ajax({
                        showLoader: true,
                        url: $(options.submit_form).attr("action"),
                        data: $(options.submit_form).serialize(),
                        type: "POST",
                        dataType: 'json'
                    }).done(function (result) {

                        if (result) {
                            if (result.success) {

                                if (window.ga) {
                                    window.ga('send',
                                            {hitType: 'event', eventCategory: 'Newsletter', eventAction: 'click', eventLabel: 'Iscrizione newsletter'}
                                    );
                                }

                                me.addMsg($(options.popup_id), result.message, 'success-msg');

                                setTimeout(function () {
                                    popup.closeModal();
                                }, options.close_popup_millisec);

                            } else {
                                me.addMsg($(options.popup_id), result.message, 'error-msg');
                            }

                        }

                    });
                }
            });
        },
        addMsg: function (block, message, messageClass) {
            if (typeof (message) === 'object' && message.length > 0) {
                message.each(function (msg) {
                    this._appendMessage(block, msg, messageClass);
                }.bind(this));
            } else if (typeof (message) === 'string') {
                this._appendMessage(block, message, messageClass);
            }
        },
        _appendMessage: function (block, message, messageClass) {
            var currentMessage = null;
            var messageSection = block.find("." + messageClass + " ol");
            if (messageSection.length === 0) {
                var messageElement = new Element('div');
                messageElement.addClassName(messageClass);
                messageElement.appendChild(new Element('ol'));
                block.append(messageElement);
                currentMessage = messageElement.down();
                var newMessage = new Element('li');
                newMessage.update(message);
                currentMessage.appendChild(newMessage);
            } else {
                currentMessage = messageSection.first();
                var newMessage = new Element('li');
                newMessage.update(message);
                currentMessage.append(newMessage);
            }

        },
        removeMsg: function (block, messageClass) {

            block.find('.' + messageClass).each(function (index, el) {
                el.remove();
            });
        }

    });

    return $.filoblu.newsletter_popup;
});
